@@ -35,14 +35,15 @@ you can trace everything between your code and Foo.
 =cut
 
 package Class::Hook;
+$Class::Hook::VERSION = '0.04';
+use 5.006;
 use strict;
+use warnings;
 use Time::HiRes;
 use warnings::register;
 use Carp;
 
 
-our $VERSION = '0.03';
-
 local *autoload = *UNIVERSAL::AUTOLOAD;
 our $before = \&_default_before;
 our $after  = \&_default_after;
